@@ -20,10 +20,7 @@ ZEND_DLEXPORT int sp_zend_startup(zend_extension *extension) {
 // LCOV_EXCL_END
 
 static inline void sp_op_array_handler(zend_op_array *const op) {
-  // We need a filename, and strict mode not already enabled on this op
-  if (NULL == op->filename) {
-    return;
-  } else {
+  if (op->filename) {
     if (SPCFG(global_strict).enable) {
       op->fn_flags |= ZEND_ACC_STRICT_TYPES;
     }
@@ -57,7 +54,7 @@ ZEND_DLEXPORT zend_extension zend_extension_entry = {
     NULL,                /* op_array_dtor_func_t */
     STANDARD_ZEND_EXTENSION_PROPERTIES};
 
-static void sp_load_other_modules() {
+static void sp_load_other_modules(void) {
   // try to load other modules before initializing Snuffleupagus
   zend_module_entry *module;
   bool should_start = false;
@@ -113,6 +110,7 @@ static PHP_GINIT_FUNCTION(snuffleupagus) {
   SP_INIT_NULL(config_eval.blacklist);
   SP_INIT_NULL(config_eval.whitelist);
   SP_INIT_NULL(config_wrapper.whitelist);
+  SP_INIT_NULL(config_wrapper.php_stream_allowlist);
 #undef SP_INIT_NULL
 }
 
@@ -175,6 +173,7 @@ static PHP_GSHUTDOWN_FUNCTION(snuffleupagus) {
   FREE_LST(config_eval.blacklist);
   FREE_LST(config_eval.whitelist);
   FREE_LST(config_wrapper.whitelist);
+  FREE_LST(config_wrapper.php_stream_allowlist);
 #undef FREE_LST
 
 
@@ -208,8 +207,10 @@ PHP_RINIT_FUNCTION(snuffleupagus) {
   if (!SPG(allow_broken_configuration)) {
     if (SPG(is_config_valid) == SP_CONFIG_INVALID) {
       sp_log_err("config", "Invalid configuration file");
+      return SUCCESS;
     } else if (SPG(is_config_valid) == SP_CONFIG_NONE) {
       sp_log_warn("config", "No configuration specified via sp.configuration_file");
+      return SUCCESS;
     }
   }
 
@@ -246,7 +247,7 @@ PHP_MINFO_FUNCTION(snuffleupagus) {
   php_info_print_table_row(
       2, "snuffleupagus support",
       SPG(is_config_valid) ? "enabled" : "disabled");
-  php_info_print_table_row(2, "Version", PHP_SNUFFLEUPAGUS_VERSION "-sng (with Suhosin-NG patches)");
+  php_info_print_table_row(2, "Version", PHP_SNUFFLEUPAGUS_VERSION);
   php_info_print_table_row(2, "Valid config", valid_config);
   php_info_print_table_end();
   DISPLAY_INI_ENTRIES();
@@ -325,7 +326,7 @@ static void add_df_to_arr(zval *arr, sp_disabled_function const *const df) {
   add_next_index_zval(arr, &arr_df);
 }
 
-static void dump_config() {
+static void dump_config(void) {
   zval arr;
   php_serialize_data_t var_hash;
   smart_str buf = {0};
@@ -360,7 +361,6 @@ static void dump_config() {
   add_assoc_long(&arr, SP_TOKEN_GLOBAL "." SP_TOKEN_MAX_EXECUTION_DEPTH, SPCFG(max_execution_depth));
   add_assoc_bool(&arr, SP_TOKEN_GLOBAL "." SP_TOKEN_SERVER_ENCODE, SPCFG(server_encode));
   add_assoc_bool(&arr, SP_TOKEN_GLOBAL "." SP_TOKEN_SERVER_STRIP, SPCFG(server_strip));
-  add_assoc_bool(&arr, SP_TOKEN_GLOBAL "." SP_TOKEN_SHOW_OLD_PHP_WARNING, SPCFG(show_old_php_warning));
 
   add_assoc_bool(&arr, SP_TOKEN_AUTO_COOKIE_SECURE, SPCFG(auto_cookie_secure).enable);
   add_assoc_bool(&arr, SP_TOKEN_XXE_PROTECTION, SPCFG(xxe_protection).enable);
@@ -385,7 +385,8 @@ static void dump_config() {
   add_assoc_long(&arr, SP_TOKEN_SESSION_ENCRYPTION "." SP_TOKEN_SID_MAX_LENGTH, SPCFG(session).sid_max_length);
   add_assoc_bool(&arr, SP_TOKEN_SLOPPY_COMPARISON "." SP_TOKEN_ENABLE, SPCFG(sloppy).enable);
 
-  ADD_ASSOC_SPLIST(&arr, SP_TOKEN_ALLOW_WRAPPERS, SPCFG(wrapper).whitelist);
+  ADD_ASSOC_SPLIST(&arr, SP_TOKEN_ALLOW_WRAPPERS "." SP_TOKEN_LIST, SPCFG(wrapper).whitelist);
+  ADD_ASSOC_SPLIST(&arr, SP_TOKEN_ALLOW_WRAPPERS "." SP_TOKEN_ALLOW_PHP_STREAMS, SPCFG(wrapper).php_stream_allowlist);
 
 #undef ADD_ASSOC_SPLIST
 
@@ -499,7 +500,6 @@ static PHP_INI_MH(OnUpdateConfiguration) {
   }
 
   // set some defaults
-  SPCFG(show_old_php_warning) = true;
   SPCFG(readonly_exec).extended_checks = true;
 
   char *str = new_value->val;
@@ -604,21 +604,10 @@ static PHP_INI_MH(OnUpdateConfiguration) {
     (SPCFG(disabled_functions) && zend_hash_num_elements(SPCFG(disabled_functions))) ||
     (SPCFG(disabled_functions_ret) && zend_hash_num_elements(SPCFG(disabled_functions_ret)));
 
-  if (SPCFG(show_old_php_warning) && getenv("SP_SKIP_OLD_PHP_CHECK") == NULL) {
-    const time_t ts = time(NULL);
-    if ((PHP_VERSION_ID < 70300) ||
-        (PHP_VERSION_ID < 70400 && ts >= (time_t)1638745200L) ||
-        (PHP_VERSION_ID < 80000 && ts >= (time_t)1669590000L) ||
-        (PHP_VERSION_ID < 80100 && ts >= (time_t)1700953200L)) {
-      sp_log_warn("End-of-Life Check", "Your PHP version '" PHP_VERSION "' is not officially maintained anymore. " \
-		      "Please upgrade as soon as possible. - Note: This message can be switched off by setting " \
-		      "'sp.global.show_old_php_warning.disable();' in your rules file or by setting the environment variable SP_SKIP_OLD_PHP_CHECK=1.");
-    }
-  }
   return SUCCESS;
 }
 
-const zend_function_entry snuffleupagus_functions[] = {PHP_FE_END};
+static const zend_function_entry snuffleupagus_functions[] = {PHP_FE_END};
 
 zend_module_entry snuffleupagus_module_entry = {
     STANDARD_MODULE_HEADER,
